import * as events from '@aws-cdk/aws-events';
import * as lambda from '@aws-cdk/aws-lambda';
import * as s3 from '@aws-cdk/aws-s3';
import * as sns from '@aws-cdk/aws-sns';
import * as cdk from '@aws-cdk/core';
/**
 * @stability stable
 */
export interface ICertbotProps {
    /**
     * The comma delimited list of domains for which the Let's Encrypt certificate will be valid.
     *
     * Primary domain should be first.
     *
     * @stability stable
     */
    letsencryptDomains: string;
    /**
     * The email to associate with the Let's Encrypt certificate request.
     *
     * @stability stable
     */
    letsencryptEmail: string;
    /**
     * Any additional Lambda layers to use with the created function.
     *
     * For example Lambda Extensions
     *
     * @stability stable
     */
    hostedZoneNames: string[];
    /**
     * Hosted zone names that will be required for DNS verification with certbot.
     *
     * @stability stable
     */
    layers?: lambda.ILayerVersion[];
    /**
     * The S3 bucket to place the resulting certificates in.
     *
     * If no bucket is given one will be created automatically.
     *
     * @stability stable
     */
    bucket?: s3.Bucket;
    /**
     * The prefix to apply to the final S3 key name for the certificates.
     *
     * Default is no prefix.
     *
     * @stability stable
     */
    objectPrefix?: string;
    /**
     * The numbers of days left until the prior cert expires before issuing a new one.
     *
     * Default is 30 days
     *
     * @stability stable
     */
    reIssueDays?: number;
    /**
     * Set the preferred certificate chain.
     *
     * Default None.
     *
     * @stability stable
     */
    preferredChain?: string;
    /**
     * The SNS topic to notify when a new cert is issued.
     *
     * @stability stable
     */
    snsTopic?: sns.Topic;
    /**
     * Whether or not to enable Lambda Insights.
     *
     * @stability stable
     */
    enableInsights?: boolean;
    /**
     * Insights layer ARN for your region.
     *
     * Defaults to US-EAST-1
     *
     * @stability stable
     */
    insightsARN?: string;
    /**
     * The timeout duration for Lambda function.
     *
     * @stability stable
     */
    timeout?: cdk.Duration;
    /**
     * The schedule for the certificate check trigger.
     *
     * Defaults to once every Sunday.
     *
     * @stability stable
     */
    schedule?: events.Schedule;
    /**
     * Whether or not to schedule a trigger to run the function after each deployment.
     *
     * @stability stable
     */
    runOnDeploy?: boolean;
    /**
     * How many minutes to wait before running the post deployment Lambda trigger.
     *
     * Defaults to 10 minutes
     *
     * @stability stable
     */
    runOnDeployWaitMinutes?: number;
}
/**
 * @stability stable
 */
export declare class Certbot extends cdk.Construct {
    /**
     * @stability stable
     */
    readonly handler: lambda.Function;
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: ICertbotProps);
}
